==> ocaml_3.04.orig.tar.gz: ocaml-3.04/debugger/history.ml <==
(***********************************************************************)
(*                                                                     *)
(*                           Objective Caml                            *)
(*                                                                     *)
(*          Jerome Vouillon, projet Cristal, INRIA Rocquencourt        *)
(*          Objective Caml port by John Malecki and Xavier Leroy       *)
(*                                                                     *)
(*  Copyright 1996 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  All rights reserved.  This file is distributed    *)
(*  under the terms of the Q Public License version 1.0.               *)
(*                                                                     *)
(***********************************************************************)

(* $Id: history.ml,v 1.4 1999/11/17 18:57:24 xleroy Exp $ *)

open Checkpoints
open Misc
open Primitives
open Debugger_config

let history = ref ([] : int list)

let empty_history () =
  history := []

let add_current_time () =
  let time = current_time () in
    if history = ref [] then
      history := [time]
    else if time <> List.hd !history then
      history := list_truncate !history_size (time::!history)

let previous_time_1 () =
  match !history with
    _::((time::_) as hist) ->
      history := hist; time
  | _ ->
      prerr_endline "No more information."; raise Toplevel

let rec previous_time n =
  if n = 1
  then previous_time_1()
  else begin ignore(previous_time_1()); previous_time(n-1) end

==> ocaml_3.11.1.orig.tar.gz: ocaml-3.11.1/debugger/history.ml <==
(***********************************************************************)
(*                                                                     *)
(*                           Objective Caml                            *)
(*                                                                     *)
(*          Jerome Vouillon, projet Cristal, INRIA Rocquencourt        *)
(*          Objective Caml port by John Malecki and Xavier Leroy       *)
(*                                                                     *)
(*  Copyright 1996 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  All rights reserved.  This file is distributed    *)
(*  under the terms of the Q Public License version 1.0.               *)
(*                                                                     *)
(***********************************************************************)

(* $Id: history.ml,v 1.5.28.1 2009/04/02 09:44:21 xclerc Exp $ *)

open Int64ops
open Checkpoints
open Primitives
open Debugger_config

let history = ref ([] : int64 list)

let empty_history () =
  history := []

let add_current_time () =
  let time = current_time () in
    if !history = [] then
      history := [time]
    else if time <> List.hd !history then
      history := list_truncate !history_size (time::!history)

let previous_time_1 () =
  match !history with
    _::((time::_) as hist) ->
      history := hist; time
  | _ ->
      prerr_endline "No more information."; raise Toplevel

let rec previous_time n =
  if n = _1
  then previous_time_1()
  else begin ignore(previous_time_1()); previous_time(pre64 n) end
